==> netbluemind4-4.1.48921.tar.gz: netbluemind4-4.1.48921/netbluemind/core/container/model/ItemChangelog.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ItemChangelog :
    def __init__( self):
        self.entries = None
        pass

class __ItemChangelogSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ItemChangelog()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.ItemChangeLogEntry import ItemChangeLogEntry
        from netbluemind.core.container.model.ItemChangeLogEntry import __ItemChangeLogEntrySerDer__
        entriesValue = value['entries']
        instance.entries = serder.ListSerDer(__ItemChangeLogEntrySerDer__()).parse(entriesValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.ItemChangeLogEntry import ItemChangeLogEntry
        from netbluemind.core.container.model.ItemChangeLogEntry import __ItemChangeLogEntrySerDer__
        entriesValue = value.entries
        instance["entries"] = serder.ListSerDer(__ItemChangeLogEntrySerDer__()).encode(entriesValue)
        return instance

==> netbluemind5-5.0.7187.tar.gz: netbluemind5-5.0.7187/netbluemind/core/container/model/ItemChangelog.py <==
#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
#
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
#
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder


class ItemChangelog:
    def __init__(self):
        self.entries = None
        pass


class __ItemChangelogSerDer__:
    def __init__(self):
        pass

    def parse(self, value):
        if (value == None):
            return None
        instance = ItemChangelog()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.core.container.model.ItemChangeLogEntry import ItemChangeLogEntry
        from netbluemind.core.container.model.ItemChangeLogEntry import __ItemChangeLogEntrySerDer__
        entriesValue = value['entries']
        instance.entries = serder.ListSerDer(
            __ItemChangeLogEntrySerDer__()).parse(entriesValue)
        return instance

    def encode(self, value):
        if (value == None):
            return None
        instance = dict()
        self.encodeInternal(value, instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.core.container.model.ItemChangeLogEntry import ItemChangeLogEntry
        from netbluemind.core.container.model.ItemChangeLogEntry import __ItemChangeLogEntrySerDer__
        entriesValue = value.entries
        instance["entries"] = serder.ListSerDer(
            __ItemChangeLogEntrySerDer__()).encode(entriesValue)
        return instance
